@@ -35,7 +35,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use Mouse;
 use Carp;
@@ -155,10 +155,6 @@ sub make_object
     $accession = $object->{id};
   }
 
-  if ($object->{is_obsolete}) {
-    $object->{name} .= ' (obsolete ' . $object->{id} . ')'
-  }
-
   $object->{accession} = $accession;
   $object->{db_name} = $db_name;
 
